@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized );
 
-our $VERSION = '1.802';
+our $VERSION = '1.803';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitSubroutinePrototypes)
@@ -449,7 +449,7 @@ MCE::Map - Parallel map model similar to the native map function
 
 =head1 VERSION
 
-This document describes MCE::Map version 1.802
+This document describes MCE::Map version 1.803
 
 =head1 SYNOPSIS
 
@@ -540,8 +540,8 @@ The following list options which may be overridden when loading the module.
        thaw => \&decode_sereal          # \&Storable::thaw
    ;
 
-From MCE 1.8 onwards, Sereal 3.008+ is loaded automatically if available with
-Perl 5.12 or later. Specify C<Sereal => 0> if Storable is desired instead.
+From MCE 1.8 onwards, Sereal 3.008+ is loaded automatically if available.
+Specify C<Sereal => 0> to use Storable instead.
 
    use MCE::Map Sereal => 0;
 
